@@ -20,6 +20,7 @@
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  */
 
+#include <fnmatch.h>
 #include <pwd.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -36,12 +37,11 @@
 #include <libgnome/libgnome.h>
 #include <libgnomevfs/gnome-vfs.h>
 #include <libgnomevfs/gnome-vfs-mime.h>
+#include <gconf/gconf-client.h>
 #include "file-utils.h"
 
-
 #define BUF_SIZE 4096
 
-
 gboolean
 path_is_file (const gchar *path)
 {
@@ -220,7 +220,7 @@ file_copy (const gchar *from,
 		return FALSE;
 
 	dest_dir = remove_level_from_path (to);
-	if (! ensure_dir_exists (dest_dir)) {
+	if (! ensure_dir_exists (dest_dir, 0755)) {
 		g_free (dest_dir);
 		fclose (fin);
 		return FALSE;
@@ -271,12 +271,30 @@ file_is_hidden (const gchar *name)
 }
 
 
-const gchar *
-file_name_from_path (const gchar *path)
+/* like g_basename but does not warns about NULL and does not
+ * alloc a new string. */
+G_CONST_RETURN gchar *
+file_name_from_path (const gchar *file_name)
 {
-	/* g_basename warns about NULL, but we accept it. */
-	if (! path) return NULL;
-	return g_basename (path);
+	register gssize base;
+	register gssize last_char;
+
+	if (file_name == NULL) 
+		return NULL;
+
+	if (file_name[0] == '\0')
+		return "";
+
+	last_char = strlen (file_name) - 1;
+
+	if (file_name [last_char] == G_DIR_SEPARATOR)
+		return "";
+
+	base = last_char;
+	while ((base >= 0) && (file_name [base] != G_DIR_SEPARATOR))
+		base--;
+
+	return file_name + base + 1;
 }
 
 
@@ -336,7 +354,8 @@ remove_ending_separator (const gchar *path)
 
 
 gboolean 
-ensure_dir_exists (const gchar *a_path)
+ensure_dir_exists (const gchar *a_path,
+		   mode_t       mode)
 {
 	if (! a_path) return FALSE;
 
@@ -355,7 +374,7 @@ ensure_dir_exists (const gchar *a_path)
 				}
 
 			if (! path_is_dir (path)) {
-					if (mkdir (path, 0755) < 0) {
+					if (mkdir (path, mode) < 0) {
 						g_warning ("directory creation failed: %s.", path);
 						g_free (path);
 						return FALSE;
@@ -372,9 +391,17 @@ ensure_dir_exists (const gchar *a_path)
 
 
 gboolean
-file_extension_is (char *filename, char *ext)
+file_extension_is (const char *filename, 
+		   const char *ext)
 {
-	return ! strcasecmp (filename + strlen (filename) - strlen (ext), ext);
+	int filename_l, ext_l;
+	
+	filename_l = strlen (filename);
+	ext_l = strlen (ext);
+	
+	if (filename_l < ext_l)
+		return FALSE;
+	return strcasecmp (filename + filename_l - ext_l, ext) == 0;
 }
 
 
@@ -409,7 +436,8 @@ path_list_dup (GList *path_list)
 
 /* characters to escape */
 static gchar bad_char[] = { '$', '\'', '`', '"', '\\', '!', '?', '*',
-			    ' ', '(', ')', '[', ']', '&', '|', '@', '#'};
+			    ' ', '(', ')', '[', ']', '&', '|', '@', '#',
+			    ';', '=', '-' };
 
 /* the size of bad_char */
 static const gint bad_chars = sizeof (bad_char) / sizeof (gchar);
@@ -467,6 +495,59 @@ shell_escape (const gchar *filename)
 }
 
 
+static gchar *
+get_terminal ()
+{
+	GConfClient *client;
+	gchar *result;
+	gchar *terminal = NULL;
+	gchar *exec_flag = NULL;
+
+	client = gconf_client_get_default ();
+	terminal = gconf_client_get_string (client, "/desktop/gnome/applications/terminal/exec", NULL);
+	g_object_unref (G_OBJECT (client));
+	
+	if (terminal) 
+		exec_flag = gconf_client_get_string (client, "/desktop/gnome/applications/terminal/exec_arg", NULL);
+
+	if (terminal == NULL) {
+		char *check;
+
+		check = g_find_program_in_path ("gnome-terminal");
+		if (check != NULL) {
+			terminal = check;
+			/* Note that gnome-terminal takes -x and
+			 * as -e in gnome-terminal is broken we use that. */
+			exec_flag = g_strdup ("-x");
+		} else {
+			if (check == NULL)
+				check = g_find_program_in_path ("nxterm");
+			if (check == NULL)
+				check = g_find_program_in_path ("color-xterm");
+			if (check == NULL)
+				check = g_find_program_in_path ("rxvt");
+			if (check == NULL)
+				check = g_find_program_in_path ("xterm");
+			if (check == NULL)
+				check = g_find_program_in_path ("dtterm");
+			if (check == NULL) {
+				g_warning (_("Cannot find a terminal, using "
+					     "xterm, even if it may not work"));
+				check = g_strdup ("xterm");
+			}
+			terminal = check;
+			exec_flag = g_strdup ("-e");
+		}
+	}
+
+	if (terminal == NULL)
+		return NULL;
+
+	result = g_strconcat (terminal, " ", exec_flag, NULL);
+	return result;
+}
+
+
 gchar *
 application_get_command (const GnomeVFSMimeApplication *app)
 {
@@ -476,7 +557,10 @@ application_get_command (const GnomeVFSMimeApplication *app)
 		char *terminal;
 		char *command_to_exec;
 
-		terminal = gnome_config_get_string ("Gnome/Applications/Terminal=xterm -e");
+		terminal = get_terminal ();
+		if (terminal == NULL)
+			return NULL;
+
 		command_to_exec = shell_escape (app->command);
 		command = g_strconcat (terminal,
 				       " ",
@@ -489,3 +573,44 @@ application_get_command (const GnomeVFSMimeApplication *app)
 
 	return command;
 }
+
+
+#define CASE_INSENSITIVE (1 << 4)
+
+
+gboolean
+match_patterns (char       **patterns, 
+		const char  *string)
+{
+	gint i;
+	gint result;
+       
+	if (patterns[0] == NULL)
+		return TRUE;
+	
+	if (string == NULL)
+		return FALSE;
+	
+	result = FNM_NOMATCH;
+	i = 0;
+	while ((result != 0) && (patterns[i] != NULL)) {
+		result = fnmatch (patterns[i], string, CASE_INSENSITIVE);
+		i++;
+	}
+	
+	return (result == 0);
+}
+
+
+char **
+search_util_get_patterns (const char *pattern_string)
+{
+	gchar **patterns;
+	gint    i;
+	
+	patterns = g_strsplit (pattern_string, ";", 10);
+	for (i = 0; patterns[i] != NULL; i++) 
+		patterns[i] = g_strstrip (patterns[i]);
+	
+	return patterns;
+}
