@@ -24,7 +24,7 @@
 #include <string.h>
 #include <time.h>
 
-#include <gtk/gtk.h>
+#include <glib.h>
 #include <libgnomevfs/gnome-vfs-types.h>
 #include <libgnomevfs/gnome-vfs-mime.h>
 
@@ -33,13 +33,9 @@
 #include "fr-command.h"
 #include "fr-command-rar.h"
 
-
 static void fr_command_rar_class_init  (FRCommandRarClass *class);
-
-static void fr_command_rar_init        (FRCommand *afile);
-
-static void fr_command_rar_destroy     (GtkObject *object);
-
+static void fr_command_rar_init        (FRCommand         *afile);
+static void fr_command_rar_finalize    (GObject           *object);
 
 /* Parent Class */
 
@@ -49,10 +45,11 @@ static FRCommandClass *parent_class = NULL;
 /* -- list -- */
 
 static time_t
-mktime_from_string (char *date_s, char *time_s)
+mktime_from_string (char *date_s, 
+		    char *time_s)
 {
-	struct tm tm = {0, };
-	char **fields;
+	struct tm   tm = {0, };
+	char      **fields;
 
 	/* date */
 
@@ -91,11 +88,12 @@ eat_spaces (char *line)
 
 
 static char **
-split_line (char *line, int n_fields)
+split_line (char *line, 
+	    int   n_fields)
 {
 	char **fields;
-	char *scan, *field_end;
-	int i;
+	char  *scan, *field_end;
+	int    i;
 
 	fields = g_new0 (char *, n_fields + 1);
 	fields[n_fields + 1] = NULL;
@@ -116,9 +114,9 @@ split_line (char *line, int n_fields)
 static char *
 get_last_field (char *line)
 {
-	int i;
+	int   i;
 	char *field;
-	int n = 1;
+	int   n = 1;
 
 	n--;
 	field = eat_spaces (line);
@@ -132,12 +130,13 @@ get_last_field (char *line)
 
 
 static void
-process_line (char *line, gpointer data)
+process_line (char     *line, 
+	      gpointer  data)
 {
-	FRCommand *comm = FR_COMMAND (data);
-	FRCommandRar *rar_comm = FR_COMMAND_RAR (comm);
-	char **fields;
-	char *name_field;
+	FRCommand     *comm = FR_COMMAND (data);
+	FRCommandRar  *rar_comm = FR_COMMAND_RAR (comm);
+	char         **fields;
+	char          *name_field;
 
 	g_return_if_fail (line != NULL);
 
@@ -205,6 +204,10 @@ fr_command_rar_list (FRCommand *comm)
 {
 	FR_COMMAND_RAR (comm)->list_started = FALSE;
 
+	fr_process_set_out_line_func (FR_COMMAND (comm)->process, 
+				      process_line,
+				      comm);
+
 	fr_process_clear (comm->process);
 	fr_process_begin_command (comm->process, "rar");
 	fr_process_add_arg (comm->process, "v");
@@ -215,15 +218,17 @@ fr_command_rar_list (FRCommand *comm)
 
 	fr_process_add_arg (comm->process, comm->e_filename);
 	fr_process_end_command (comm->process);
-	fr_process_start (comm->process, TRUE);
+	fr_process_start (comm->process);
 }
 
 
 static void
-fr_command_rar_add (FRCommand *comm,
-		    GList *file_list,
-		    gchar *base_dir,
-		    gboolean update)
+fr_command_rar_add (FRCommand     *comm,
+		    GList         *file_list,
+		    const char    *base_dir,
+		    gboolean       update,
+		    const char    *password,
+		    FRCompression  compression)
 {
 	GList *scan;
 
@@ -237,6 +242,17 @@ fr_command_rar_add (FRCommand *comm,
 	else
 		fr_process_add_arg (comm->process, "a");
 
+	switch (compression) {
+	case FR_COMPRESSION_VERY_FAST:
+		fr_process_add_arg (comm->process, "m1"); break;
+	case FR_COMPRESSION_FAST:
+		fr_process_add_arg (comm->process, "m2"); break;
+	case FR_COMPRESSION_NORMAL:
+		fr_process_add_arg (comm->process, "m3"); break;
+	case FR_COMPRESSION_MAXIMUM:
+		fr_process_add_arg (comm->process, "m5"); break;
+	}
+
 	/* stop switches scanning */
 	fr_process_add_arg (comm->process, "--"); 
 
@@ -251,7 +267,7 @@ fr_command_rar_add (FRCommand *comm,
 
 static void
 fr_command_rar_delete (FRCommand *comm,
-		       GList *file_list)
+		       GList     *file_list)
 {
 	GList *scan;
 
@@ -270,12 +286,13 @@ fr_command_rar_delete (FRCommand *comm,
 
 
 static void
-fr_command_rar_extract (FRCommand *comm,
-			GList *file_list,
-			char *dest_dir,
-			gboolean overwrite,
-			gboolean skip_older,
-			gboolean junk_paths)
+fr_command_rar_extract (FRCommand  *comm,
+			GList      *file_list,
+			const char *dest_dir,
+			gboolean    overwrite,
+			gboolean    skip_older,
+			gboolean    junk_paths,
+			const char *password)
 {
 	GList *scan;
 
@@ -312,7 +329,7 @@ fr_command_rar_extract (FRCommand *comm,
 
 
 static void
-fr_command_rar_handle_error (FRCommand *comm, 
+fr_command_rar_handle_error (FRCommand   *comm, 
 			     FRProcError *error)
 {
 	if ((error->type == FR_PROC_ERROR_GENERIC) 
@@ -324,14 +341,13 @@ fr_command_rar_handle_error (FRCommand *comm,
 static void 
 fr_command_rar_class_init (FRCommandRarClass *class)
 {
+        GObjectClass *gobject_class = G_OBJECT_CLASS (class);
         FRCommandClass *afc;
-        GtkObjectClass *object_class;
 
-        parent_class = gtk_type_class (FR_COMMAND_TYPE);
-        object_class = (GtkObjectClass*) class;
+        parent_class = g_type_class_peek_parent (class);
 	afc = (FRCommandClass*) class;
 
-        object_class->destroy = fr_command_rar_destroy;
+	gobject_class->finalize = fr_command_rar_finalize;
 
         afc->list         = fr_command_rar_list;
 	afc->add          = fr_command_rar_add;
@@ -349,56 +365,59 @@ fr_command_rar_init (FRCommand *comm)
 	comm->propExtractCanAvoidOverwrite = TRUE;
 	comm->propExtractCanSkipOlder      = TRUE;
 	comm->propExtractCanJunkPaths      = TRUE;
+	comm->propPassword                 = FALSE;
+	comm->propTest                     = FALSE;
 }
 
 
 static void 
-fr_command_rar_destroy (GtkObject *object)
+fr_command_rar_finalize (GObject *object)
 {
         g_return_if_fail (object != NULL);
-        g_return_if_fail (IS_FR_COMMAND_RAR (object));
+        g_return_if_fail (FR_IS_COMMAND_RAR (object));
 
-	 /* Chain up */
-        if (GTK_OBJECT_CLASS (parent_class)->destroy)
-                (* GTK_OBJECT_CLASS (parent_class)->destroy) (object);
+	/* Chain up */
+        if (G_OBJECT_CLASS (parent_class)->finalize)
+		G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
 
-GtkType
+GType
 fr_command_rar_get_type ()
 {
-        static guint fr_command_rar_type = 0;
+        static guint type = 0;
 
-        if (!fr_command_rar_type) {
-                GtkTypeInfo fr_command_rar_info = {
-                        "FRCommandRar",
-                        sizeof (FRCommandRar),
-                        sizeof (FRCommandRarClass),
-                        (GtkClassInitFunc) fr_command_rar_class_init,
-                        (GtkObjectInitFunc) fr_command_rar_init,
-                        /* reserved_1 */ NULL,
-                        /* reserved_2 */ NULL,
-                        (GtkClassInitFunc) NULL,
-                };
-                fr_command_rar_type = gtk_type_unique (fr_command_get_type(), 
-						       &fr_command_rar_info);
+        if (! type) {
+                GTypeInfo type_info = {
+			sizeof (FRCommandRarClass),
+			NULL,
+			NULL,
+			(GClassInitFunc) fr_command_rar_class_init,
+			NULL,
+			NULL,
+			sizeof (FRCommandRar),
+			0,
+			(GInstanceInitFunc) fr_command_rar_init
+		};
+
+		type = g_type_register_static (FR_TYPE_COMMAND,
+					       "FRCommandRar",
+					       &type_info,
+					       0);
         }
 
-        return fr_command_rar_type;
+        return type;
 }
 
 
 FRCommand *
-fr_command_rar_new (FRProcess *process,
-		    char *filename)
+fr_command_rar_new (FRProcess  *process,
+		    const char *filename)
 {
 	FRCommand *comm;
 
-	comm = FR_COMMAND (gtk_type_new (fr_command_rar_get_type ()));
+	comm = FR_COMMAND (g_object_new (FR_TYPE_COMMAND_RAR, NULL));
 	fr_command_construct (comm, process, filename);
-	fr_process_set_proc_line_func (FR_COMMAND (comm)->process, 
-				       process_line,
-				       comm);
 
 	return comm;
 }
