@@ -46,10 +46,10 @@ enum {
 	FILE_MENU_OPEN,
 	FILE_MENU_VIEW,
 	FILE_MENU_SEP2,
-	FILE_MENU_MOVE_ARCHIVE,
-	FILE_MENU_COPY_ARCHIVE,
-	FILE_MENU_DELETE_ARCHIVE,
 	FILE_MENU_RANAME_ARCHIVE,
+	FILE_MENU_COPY_ARCHIVE,
+	FILE_MENU_MOVE_ARCHIVE,
+	FILE_MENU_DELETE_ARCHIVE,
 	FILE_MENU_SEP3,
 	FILE_MENU_ARCHIVE_PROP,
 	FILE_MENU_SEP4,
@@ -94,8 +94,8 @@ GnomeUIInfo file_menu[] = {
 	GNOMEUIINFO_SEPARATOR,
 
 	{ GNOME_APP_UI_ITEM, 
-	  N_("_Move"), N_("Move current archive to another folder"), 
-	  move_archive_cb, NULL, NULL,
+	  N_("_Rename"), N_("Rename current archive"), 
+	  rename_archive_cb, NULL, NULL,
 	  GNOME_APP_PIXMAP_NONE, 0,
 	  0, 0, NULL },
 
@@ -105,24 +105,24 @@ GnomeUIInfo file_menu[] = {
 	  GNOME_APP_PIXMAP_NONE, 0,
 	  0, 0, NULL },
 
+	{ GNOME_APP_UI_ITEM, 
+	  N_("_Move"), N_("Move current archive to another folder"), 
+	  move_archive_cb, NULL, NULL,
+	  GNOME_APP_PIXMAP_NONE, 0,
+	  0, 0, NULL },
+
 	{ GNOME_APP_UI_ITEM, 
 	  N_("_Delete"), N_("Delete current archive from disk"), 
 	  delete_archive_cb, NULL, NULL,
 	  GNOME_APP_PIXMAP_STOCK, GTK_STOCK_DELETE,
 	  0, 0, NULL },
 
-	{ GNOME_APP_UI_ITEM, 
-	  N_("_Rename"), N_("Rename current archive"), 
-	  rename_archive_cb, NULL, NULL,
-	  GNOME_APP_PIXMAP_NONE, 0,
-	  0, 0, NULL },
-
 	GNOMEUIINFO_SEPARATOR,
 
 	{ GNOME_APP_UI_ITEM,
-	  N_("_Information"), N_("Show information about the archive"),
+	  N_("_Properties"), N_("Show archive properties"),
 	  dlg_prop, NULL, NULL,
-	  GNOME_APP_PIXMAP_NONE, 0,
+	  GNOME_APP_PIXMAP_STOCK, GTK_STOCK_PROPERTIES,
 	  'i', GDK_CONTROL_MASK, NULL },
 
 	GNOMEUIINFO_SEPARATOR,
